dot-method_process_definition: Method process definition

.method_process_definitionR Documentation

Method process definition

Description

Method process definition

Usage

.method_process_definition(definition, return_function)

Arguments

definition

A definition, see definition()

return_function

Whether to return a function that allows you to override the default parameters, or just return the method meta data as is.


dynwrap documentation built on April 1, 2026, 1:06 a.m.